# OIDCProxyDomainNameMapping

A mapping of internal name to external name so oidc-proxy can rewrite them.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**internal_name** | **str** | The internal domain name that we used in the proxy. | 
**external_name** | **str** | The external domain name that we want to be exposed. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


